/****************************************************************************
** Meta object code from reading C++ file 'imagedocument.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../kquickimageeditor-0.3.0/src/code/imagedocument.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'imagedocument.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_ImageDocument_t {
    QByteArrayData data[25];
    char stringdata0[178];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ImageDocument_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ImageDocument_t qt_meta_stringdata_ImageDocument = {
    {
QT_MOC_LITERAL(0, 0, 13), // "ImageDocument"
QT_MOC_LITERAL(1, 14, 11), // "pathChanged"
QT_MOC_LITERAL(2, 26, 0), // ""
QT_MOC_LITERAL(3, 27, 3), // "url"
QT_MOC_LITERAL(4, 31, 12), // "imageChanged"
QT_MOC_LITERAL(5, 44, 13), // "editedChanged"
QT_MOC_LITERAL(6, 58, 6), // "rotate"
QT_MOC_LITERAL(7, 65, 5), // "angle"
QT_MOC_LITERAL(8, 71, 6), // "mirror"
QT_MOC_LITERAL(9, 78, 10), // "horizontal"
QT_MOC_LITERAL(10, 89, 8), // "vertical"
QT_MOC_LITERAL(11, 98, 4), // "crop"
QT_MOC_LITERAL(12, 103, 1), // "x"
QT_MOC_LITERAL(13, 105, 1), // "y"
QT_MOC_LITERAL(14, 107, 5), // "width"
QT_MOC_LITERAL(15, 113, 6), // "height"
QT_MOC_LITERAL(16, 120, 6), // "resize"
QT_MOC_LITERAL(17, 127, 4), // "undo"
QT_MOC_LITERAL(18, 132, 6), // "cancel"
QT_MOC_LITERAL(19, 139, 4), // "save"
QT_MOC_LITERAL(20, 144, 6), // "saveAs"
QT_MOC_LITERAL(21, 151, 8), // "location"
QT_MOC_LITERAL(22, 160, 4), // "path"
QT_MOC_LITERAL(23, 165, 5), // "image"
QT_MOC_LITERAL(24, 171, 6) // "edited"

    },
    "ImageDocument\0pathChanged\0\0url\0"
    "imageChanged\0editedChanged\0rotate\0"
    "angle\0mirror\0horizontal\0vertical\0crop\0"
    "x\0y\0width\0height\0resize\0undo\0cancel\0"
    "save\0saveAs\0location\0path\0image\0edited"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ImageDocument[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      11,   14, // methods
       3,  102, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   69,    2, 0x06 /* Public */,
       4,    0,   72,    2, 0x06 /* Public */,
       5,    0,   73,    2, 0x06 /* Public */,

 // methods: name, argc, parameters, tag, flags
       6,    1,   74,    2, 0x02 /* Public */,
       8,    2,   77,    2, 0x02 /* Public */,
      11,    4,   82,    2, 0x02 /* Public */,
      16,    2,   91,    2, 0x02 /* Public */,
      17,    0,   96,    2, 0x02 /* Public */,
      18,    0,   97,    2, 0x02 /* Public */,
      19,    0,   98,    2, 0x02 /* Public */,
      20,    1,   99,    2, 0x02 /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::QUrl,    3,
    QMetaType::Void,
    QMetaType::Void,

 // methods: parameters
    QMetaType::Void, QMetaType::Int,    7,
    QMetaType::Void, QMetaType::Bool, QMetaType::Bool,    9,   10,
    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int,   12,   13,   14,   15,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,   14,   15,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Bool,
    QMetaType::Bool, QMetaType::QUrl,   21,

 // properties: name, type, flags
      22, QMetaType::QUrl, 0x00495103,
      23, QMetaType::QImage, 0x00495001,
      24, QMetaType::Bool, 0x00495103,

 // properties: notify_signal_id
       0,
       1,
       2,

       0        // eod
};

void ImageDocument::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<ImageDocument *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->pathChanged((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        case 1: _t->imageChanged(); break;
        case 2: _t->editedChanged(); break;
        case 3: _t->rotate((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->mirror((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 5: _t->crop((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4]))); break;
        case 6: _t->resize((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 7: _t->undo(); break;
        case 8: _t->cancel(); break;
        case 9: { bool _r = _t->save();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 10: { bool _r = _t->saveAs((*reinterpret_cast< const QUrl(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (ImageDocument::*)(const QUrl & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ImageDocument::pathChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (ImageDocument::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ImageDocument::imageChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (ImageDocument::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ImageDocument::editedChanged)) {
                *result = 2;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<ImageDocument *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QUrl*>(_v) = _t->path(); break;
        case 1: *reinterpret_cast< QImage*>(_v) = _t->image(); break;
        case 2: *reinterpret_cast< bool*>(_v) = _t->edited(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<ImageDocument *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setPath(*reinterpret_cast< QUrl*>(_v)); break;
        case 2: _t->setEdited(*reinterpret_cast< bool*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject ImageDocument::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_ImageDocument.data,
    qt_meta_data_ImageDocument,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *ImageDocument::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ImageDocument::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ImageDocument.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ImageDocument::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 11;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 3;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void ImageDocument::pathChanged(const QUrl & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void ImageDocument::imageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ImageDocument::editedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
