/****************************************************************************
** Meta object code from reading C++ file 'resizehandle.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../kquickimageeditor-0.3.0/src/code/resizehandle.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'resizehandle.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_ResizeHandle_t {
    QByteArrayData data[17];
    char stringdata0[177];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ResizeHandle_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ResizeHandle_t qt_meta_stringdata_ResizeHandle = {
    {
QT_MOC_LITERAL(0, 0, 12), // "ResizeHandle"
QT_MOC_LITERAL(1, 13, 19), // "resizeCornerChanged"
QT_MOC_LITERAL(2, 33, 0), // ""
QT_MOC_LITERAL(3, 34, 20), // "resizeBlockedChanged"
QT_MOC_LITERAL(4, 55, 16), // "rectangleChanged"
QT_MOC_LITERAL(5, 72, 13), // "resizeBlocked"
QT_MOC_LITERAL(6, 86, 9), // "rectangle"
QT_MOC_LITERAL(7, 96, 11), // "QQuickItem*"
QT_MOC_LITERAL(8, 108, 6), // "Corner"
QT_MOC_LITERAL(9, 115, 4), // "Left"
QT_MOC_LITERAL(10, 120, 7), // "TopLeft"
QT_MOC_LITERAL(11, 128, 3), // "Top"
QT_MOC_LITERAL(12, 132, 8), // "TopRight"
QT_MOC_LITERAL(13, 141, 5), // "Right"
QT_MOC_LITERAL(14, 147, 11), // "BottomRight"
QT_MOC_LITERAL(15, 159, 6), // "Bottom"
QT_MOC_LITERAL(16, 166, 10) // "BottomLeft"

    },
    "ResizeHandle\0resizeCornerChanged\0\0"
    "resizeBlockedChanged\0rectangleChanged\0"
    "resizeBlocked\0rectangle\0QQuickItem*\0"
    "Corner\0Left\0TopLeft\0Top\0TopRight\0Right\0"
    "BottomRight\0Bottom\0BottomLeft"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ResizeHandle[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       3,   14, // methods
       2,   32, // properties
       1,   40, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   29,    2, 0x06 /* Public */,
       3,    0,   30,    2, 0x06 /* Public */,
       4,    0,   31,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // properties: name, type, flags
       5, QMetaType::Bool, 0x00495001,
       6, 0x80000000 | 7, 0x0049510b,

 // properties: notify_signal_id
       1,
       2,

 // enums: name, alias, flags, count, data
       8,    8, 0x0,    8,   45,

 // enum data: key, value
       9, uint(ResizeHandle::Left),
      10, uint(ResizeHandle::TopLeft),
      11, uint(ResizeHandle::Top),
      12, uint(ResizeHandle::TopRight),
      13, uint(ResizeHandle::Right),
      14, uint(ResizeHandle::BottomRight),
      15, uint(ResizeHandle::Bottom),
      16, uint(ResizeHandle::BottomLeft),

       0        // eod
};

void ResizeHandle::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<ResizeHandle *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->resizeCornerChanged(); break;
        case 1: _t->resizeBlockedChanged(); break;
        case 2: _t->rectangleChanged(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (ResizeHandle::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ResizeHandle::resizeCornerChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (ResizeHandle::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ResizeHandle::resizeBlockedChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (ResizeHandle::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ResizeHandle::rectangleChanged)) {
                *result = 2;
                return;
            }
        }
    } else if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuickItem* >(); break;
        }
    }

#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<ResizeHandle *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< bool*>(_v) = _t->resizeBlocked(); break;
        case 1: *reinterpret_cast< QQuickItem**>(_v) = _t->rectangle(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<ResizeHandle *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setRectangle(*reinterpret_cast< QQuickItem**>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject ResizeHandle::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickItem::staticMetaObject>(),
    qt_meta_stringdata_ResizeHandle.data,
    qt_meta_data_ResizeHandle,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *ResizeHandle::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ResizeHandle::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ResizeHandle.stringdata0))
        return static_cast<void*>(this);
    return QQuickItem::qt_metacast(_clname);
}

int ResizeHandle::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 3;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 2;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void ResizeHandle::resizeCornerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ResizeHandle::resizeBlockedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ResizeHandle::rectangleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
