/****************************************************************************
** Meta object code from reading C++ file 'imageitem.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../kquickimageeditor-0.3.0/src/code/imageitem.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'imageitem.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_ImageItem_t {
    QByteArrayData data[28];
    char stringdata0[395];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ImageItem_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ImageItem_t qt_meta_stringdata_ImageItem = {
    {
QT_MOC_LITERAL(0, 0, 9), // "ImageItem"
QT_MOC_LITERAL(1, 10, 18), // "nativeWidthChanged"
QT_MOC_LITERAL(2, 29, 0), // ""
QT_MOC_LITERAL(3, 30, 19), // "nativeHeightChanged"
QT_MOC_LITERAL(4, 50, 15), // "fillModeChanged"
QT_MOC_LITERAL(5, 66, 12), // "imageChanged"
QT_MOC_LITERAL(6, 79, 11), // "nullChanged"
QT_MOC_LITERAL(7, 91, 19), // "paintedWidthChanged"
QT_MOC_LITERAL(8, 111, 20), // "paintedHeightChanged"
QT_MOC_LITERAL(9, 132, 22), // "verticalPaddingChanged"
QT_MOC_LITERAL(10, 155, 24), // "horizontalPaddingChanged"
QT_MOC_LITERAL(11, 180, 17), // "updatePaintedRect"
QT_MOC_LITERAL(12, 198, 5), // "image"
QT_MOC_LITERAL(13, 204, 11), // "nativeWidth"
QT_MOC_LITERAL(14, 216, 12), // "nativeHeight"
QT_MOC_LITERAL(15, 229, 12), // "paintedWidth"
QT_MOC_LITERAL(16, 242, 13), // "paintedHeight"
QT_MOC_LITERAL(17, 256, 15), // "verticalPadding"
QT_MOC_LITERAL(18, 272, 17), // "horizontalPadding"
QT_MOC_LITERAL(19, 290, 8), // "fillMode"
QT_MOC_LITERAL(20, 299, 8), // "FillMode"
QT_MOC_LITERAL(21, 308, 4), // "null"
QT_MOC_LITERAL(22, 313, 7), // "Stretch"
QT_MOC_LITERAL(23, 321, 17), // "PreserveAspectFit"
QT_MOC_LITERAL(24, 339, 18), // "PreserveAspectCrop"
QT_MOC_LITERAL(25, 358, 4), // "Tile"
QT_MOC_LITERAL(26, 363, 14), // "TileVertically"
QT_MOC_LITERAL(27, 378, 16) // "TileHorizontally"

    },
    "ImageItem\0nativeWidthChanged\0\0"
    "nativeHeightChanged\0fillModeChanged\0"
    "imageChanged\0nullChanged\0paintedWidthChanged\0"
    "paintedHeightChanged\0verticalPaddingChanged\0"
    "horizontalPaddingChanged\0updatePaintedRect\0"
    "image\0nativeWidth\0nativeHeight\0"
    "paintedWidth\0paintedHeight\0verticalPadding\0"
    "horizontalPadding\0fillMode\0FillMode\0"
    "null\0Stretch\0PreserveAspectFit\0"
    "PreserveAspectCrop\0Tile\0TileVertically\0"
    "TileHorizontally"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ImageItem[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      10,   14, // methods
       9,   74, // properties
       1,  110, // enums/sets
       0,    0, // constructors
       0,       // flags
       9,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   64,    2, 0x06 /* Public */,
       3,    0,   65,    2, 0x06 /* Public */,
       4,    0,   66,    2, 0x06 /* Public */,
       5,    0,   67,    2, 0x06 /* Public */,
       6,    0,   68,    2, 0x06 /* Public */,
       7,    0,   69,    2, 0x06 /* Public */,
       8,    0,   70,    2, 0x06 /* Public */,
       9,    0,   71,    2, 0x06 /* Public */,
      10,    0,   72,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      11,    0,   73,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,

 // properties: name, type, flags
      12, QMetaType::QImage, 0x00495107,
      13, QMetaType::Int, 0x00495001,
      14, QMetaType::Int, 0x00495001,
      15, QMetaType::Int, 0x00495001,
      16, QMetaType::Int, 0x00495001,
      17, QMetaType::Int, 0x00495001,
      18, QMetaType::Int, 0x00495001,
      19, 0x80000000 | 20, 0x0049510b,
      21, QMetaType::Bool, 0x00495001,

 // properties: notify_signal_id
       3,
       0,
       1,
       5,
       6,
       7,
       8,
       2,
       4,

 // enums: name, alias, flags, count, data
      20,   20, 0x0,    6,  115,

 // enum data: key, value
      22, uint(ImageItem::Stretch),
      23, uint(ImageItem::PreserveAspectFit),
      24, uint(ImageItem::PreserveAspectCrop),
      25, uint(ImageItem::Tile),
      26, uint(ImageItem::TileVertically),
      27, uint(ImageItem::TileHorizontally),

       0        // eod
};

void ImageItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<ImageItem *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->nativeWidthChanged(); break;
        case 1: _t->nativeHeightChanged(); break;
        case 2: _t->fillModeChanged(); break;
        case 3: _t->imageChanged(); break;
        case 4: _t->nullChanged(); break;
        case 5: _t->paintedWidthChanged(); break;
        case 6: _t->paintedHeightChanged(); break;
        case 7: _t->verticalPaddingChanged(); break;
        case 8: _t->horizontalPaddingChanged(); break;
        case 9: _t->updatePaintedRect(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (ImageItem::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ImageItem::nativeWidthChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (ImageItem::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ImageItem::nativeHeightChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (ImageItem::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ImageItem::fillModeChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (ImageItem::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ImageItem::imageChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (ImageItem::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ImageItem::nullChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (ImageItem::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ImageItem::paintedWidthChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (ImageItem::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ImageItem::paintedHeightChanged)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (ImageItem::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ImageItem::verticalPaddingChanged)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (ImageItem::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ImageItem::horizontalPaddingChanged)) {
                *result = 8;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<ImageItem *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QImage*>(_v) = _t->image(); break;
        case 1: *reinterpret_cast< int*>(_v) = _t->nativeWidth(); break;
        case 2: *reinterpret_cast< int*>(_v) = _t->nativeHeight(); break;
        case 3: *reinterpret_cast< int*>(_v) = _t->paintedWidth(); break;
        case 4: *reinterpret_cast< int*>(_v) = _t->paintedHeight(); break;
        case 5: *reinterpret_cast< int*>(_v) = _t->verticalPadding(); break;
        case 6: *reinterpret_cast< int*>(_v) = _t->horizontalPadding(); break;
        case 7: *reinterpret_cast< FillMode*>(_v) = _t->fillMode(); break;
        case 8: *reinterpret_cast< bool*>(_v) = _t->isNull(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<ImageItem *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setImage(*reinterpret_cast< QImage*>(_v)); break;
        case 7: _t->setFillMode(*reinterpret_cast< FillMode*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
        ImageItem *_t = static_cast<ImageItem *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->resetImage(); break;
        default: break;
        }
    }
#endif // QT_NO_PROPERTIES
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject ImageItem::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickPaintedItem::staticMetaObject>(),
    qt_meta_stringdata_ImageItem.data,
    qt_meta_data_ImageItem,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *ImageItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ImageItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ImageItem.stringdata0))
        return static_cast<void*>(this);
    return QQuickPaintedItem::qt_metacast(_clname);
}

int ImageItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickPaintedItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 10;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 9;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 9;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 9;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 9;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 9;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void ImageItem::nativeWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ImageItem::nativeHeightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ImageItem::fillModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ImageItem::imageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void ImageItem::nullChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void ImageItem::paintedWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void ImageItem::paintedHeightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void ImageItem::verticalPaddingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void ImageItem::horizontalPaddingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
