/****************************************************************************
** Meta object code from reading C++ file 'resizerectangle.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../kquickimageeditor-0.3.0/src/code/resizerectangle.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'resizerectangle.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_ResizeRectangle_t {
    QByteArrayData data[12];
    char stringdata0[161];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ResizeRectangle_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ResizeRectangle_t qt_meta_stringdata_ResizeRectangle = {
    {
QT_MOC_LITERAL(0, 0, 15), // "ResizeRectangle"
QT_MOC_LITERAL(1, 16, 10), // "acceptSize"
QT_MOC_LITERAL(2, 27, 0), // ""
QT_MOC_LITERAL(3, 28, 14), // "insideXChanged"
QT_MOC_LITERAL(4, 43, 14), // "insideYChanged"
QT_MOC_LITERAL(5, 58, 18), // "insideWidthChanged"
QT_MOC_LITERAL(6, 77, 19), // "insideHeightChanged"
QT_MOC_LITERAL(7, 97, 22), // "handleComponentChanged"
QT_MOC_LITERAL(8, 120, 7), // "insideX"
QT_MOC_LITERAL(9, 128, 7), // "insideY"
QT_MOC_LITERAL(10, 136, 11), // "insideWidth"
QT_MOC_LITERAL(11, 148, 12) // "insideHeight"

    },
    "ResizeRectangle\0acceptSize\0\0insideXChanged\0"
    "insideYChanged\0insideWidthChanged\0"
    "insideHeightChanged\0handleComponentChanged\0"
    "insideX\0insideY\0insideWidth\0insideHeight"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ResizeRectangle[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       4,   50, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       6,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   44,    2, 0x06 /* Public */,
       3,    0,   45,    2, 0x06 /* Public */,
       4,    0,   46,    2, 0x06 /* Public */,
       5,    0,   47,    2, 0x06 /* Public */,
       6,    0,   48,    2, 0x06 /* Public */,
       7,    0,   49,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // properties: name, type, flags
       8, QMetaType::QReal, 0x00495103,
       9, QMetaType::QReal, 0x00495103,
      10, QMetaType::QReal, 0x00495103,
      11, QMetaType::QReal, 0x00495103,

 // properties: notify_signal_id
       1,
       2,
       3,
       4,

       0        // eod
};

void ResizeRectangle::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<ResizeRectangle *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->acceptSize(); break;
        case 1: _t->insideXChanged(); break;
        case 2: _t->insideYChanged(); break;
        case 3: _t->insideWidthChanged(); break;
        case 4: _t->insideHeightChanged(); break;
        case 5: _t->handleComponentChanged(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (ResizeRectangle::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ResizeRectangle::acceptSize)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (ResizeRectangle::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ResizeRectangle::insideXChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (ResizeRectangle::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ResizeRectangle::insideYChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (ResizeRectangle::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ResizeRectangle::insideWidthChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (ResizeRectangle::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ResizeRectangle::insideHeightChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (ResizeRectangle::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ResizeRectangle::handleComponentChanged)) {
                *result = 5;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<ResizeRectangle *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< qreal*>(_v) = _t->insideX(); break;
        case 1: *reinterpret_cast< qreal*>(_v) = _t->insideY(); break;
        case 2: *reinterpret_cast< qreal*>(_v) = _t->insideWidth(); break;
        case 3: *reinterpret_cast< qreal*>(_v) = _t->insideHeight(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<ResizeRectangle *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setInsideX(*reinterpret_cast< qreal*>(_v)); break;
        case 1: _t->setInsideY(*reinterpret_cast< qreal*>(_v)); break;
        case 2: _t->setInsideWidth(*reinterpret_cast< qreal*>(_v)); break;
        case 3: _t->setInsideHeight(*reinterpret_cast< qreal*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject ResizeRectangle::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickItem::staticMetaObject>(),
    qt_meta_stringdata_ResizeRectangle.data,
    qt_meta_data_ResizeRectangle,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *ResizeRectangle::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ResizeRectangle::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ResizeRectangle.stringdata0))
        return static_cast<void*>(this);
    return QQuickItem::qt_metacast(_clname);
}

int ResizeRectangle::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 6;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 4;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void ResizeRectangle::acceptSize()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ResizeRectangle::insideXChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ResizeRectangle::insideYChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ResizeRectangle::insideWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void ResizeRectangle::insideHeightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void ResizeRectangle::handleComponentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
